@@ -5,6 +5,8 @@ import click
 @click.pass_obj
 def prune(app):
     """Remove all environments."""
+    app.ensure_environment_plugin_dependencies()
+
     environment_types = app.plugins.environment.collect()
 
     environments = app.project.config.envs
@@ -17,24 +19,23 @@ def prune(app):
         if environment_type not in environment_types:
             app.abort(f'Environment `{env_name}` has unknown type: {environment_type}')
 
-        data_dir = app.get_env_directory(environment_type)
-
         environment = environment_types[environment_type](
             app.project.location,
             app.project.metadata,
             env_name,
             config,
             app.project.config.matrix_variables.get(env_name, {}),
-            data_dir,
+            app.get_env_directory(environment_type),
+            app.data_dir / 'env' / environment_type,
             app.platform,
             app.verbosity,
         )
 
         try:
             environment.check_compatibility()
-        except Exception:
+        except Exception:  # noqa: S112
             continue
 
-        if environment.exists():
+        if environment.exists() or environment.build_environment_exists():
             with app.status_waiting(f'Removing environment: {env_name}'):
                 environment.remove()
